"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.analyzeFile = void 0;
const utils_1 = require("./utils");
const after_date_1 = require("./after_date");
const on_branch_1 = require("./on_branch");
const when_1 = require("./when");
const conditions = {
    after_date: after_date_1.after_date,
    on_branch: on_branch_1.on_branch,
    when: when_1.when,
};
function isDiagnosticError(validation) {
    return validation.error === true;
}
function analyzeFile(file, { keywords, options, packageJson }) {
    const lines = file.split("\n").reduce((acc, line, index) => {
        if ((0, utils_1.startsWithKeyword)(line.trim(), keywords)) {
            return [...acc, [line, index]];
        }
        return acc;
    }, []);
    return lines.reduce((acc, [line, lineNumber]) => {
        const condition = line.substring(line.indexOf("::") + 2, line.lastIndexOf(":"));
        const param = line.substring(line.indexOf("(") + 1, line.lastIndexOf(")"));
        if (condition.startsWith("after_date")) {
            const validation = conditions.after_date(param, options);
            if (!validation.error) {
                return acc;
            }
            return [
                ...acc,
                {
                    ...validation,
                    condition,
                    line,
                    lineNumber,
                },
            ];
        }
        if (condition.startsWith("when")) {
            const validation = conditions.when(param, {
                pjson: packageJson,
                options: options === null || options === void 0 ? void 0 : options.when,
            });
            if (!validation.error) {
                return acc;
            }
            return [
                ...acc,
                {
                    ...validation,
                    condition,
                    line,
                    lineNumber,
                },
            ];
        }
        if (condition.startsWith("on_branch")) {
            const validation = conditions.on_branch(param);
            if (!validation.error) {
                return acc;
            }
            return [
                ...acc,
                {
                    ...validation,
                    condition,
                    line,
                    lineNumber,
                },
            ];
        }
        return acc;
    }, []);
}
exports.analyzeFile = analyzeFile;
//# sourceMappingURL=analyzeFile.js.map