"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFilesFromInput = void 0;
const fast_glob_1 = __importDefault(require("fast-glob"));
const fs_1 = __importDefault(require("fs"));
async function getFilesFromInput(inputs = ["."]) {
    const paths = typeof inputs === "string" ? [inputs] : inputs;
    if (paths.length === 0) {
        return [
            new Error("No path(s) provided. Run `tod --help` to see usage information."),
            undefined,
        ];
    }
    const uniqueFiles = new Set();
    for (const path of paths) {
        if (fast_glob_1.default.isDynamicPattern(path)) {
            const files = await (0, fast_glob_1.default)(path, { dot: true });
            for (const file of files) {
                uniqueFiles.add(file);
            }
            continue;
        }
        if (!fs_1.default.existsSync(path)) {
            return [new Error(`Path "${path}" does not exist.`), undefined];
        }
        if (fs_1.default.lstatSync(path).isDirectory()) {
            const files = await (0, fast_glob_1.default)(`${path}/**/*`, { dot: true });
            for (const file of files) {
                uniqueFiles.add(file);
            }
            continue;
        }
        if (fs_1.default.lstatSync(path).isFile()) {
            uniqueFiles.add(path);
            continue;
        }
        if (path === ".") {
            const files = await (0, fast_glob_1.default)("**/*", { dot: true });
            for (const file of files) {
                uniqueFiles.add(file);
            }
            continue;
        }
        throw new Error(`Invalid path: ${path}`);
    }
    return [undefined, Array.from(uniqueFiles)];
}
exports.getFilesFromInput = getFilesFromInput;
//# sourceMappingURL=getFilesFromInput.js.map