"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.printDiagnostics = void 0;
const chalk_1 = __importDefault(require("chalk"));
const easy_table_1 = __importDefault(require("easy-table"));
const typescript_1 = require("typescript");
function getCategory(category) {
    switch (category) {
        case typescript_1.DiagnosticCategory.Warning: {
            return chalk_1.default.yellow("warning");
        }
        case typescript_1.DiagnosticCategory.Error: {
            return chalk_1.default.red("error");
        }
        default: {
            return chalk_1.default.grey("unknown");
        }
    }
}
function printDiagnostics(diagnostics, file) {
    console.log(`${chalk_1.default.underline(file)}`);
    const t = new easy_table_1.default();
    diagnostics.forEach(({ category, condition, lineNumber, message }) => {
        t.cell("Line number", `  ${chalk_1.default.grey(lineNumber)}`);
        t.cell("Category", getCategory(category));
        t.cell("Message", message);
        t.cell("Condition", chalk_1.default.grey(condition));
        t.newRow();
    });
    console.log(t.print());
}
exports.printDiagnostics = printDiagnostics;
//# sourceMappingURL=printDiagnostics.js.map