"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGitBranch = exports.pipe = exports.getJsonFromFile = exports.getSplitPackageVersion = exports.getWarningWhen = exports.startsWithKeyword = exports.getWarningPeriod = exports.parseWarnWhenOption = exports.parseWarnOption = exports.parseOption = exports.isValidWarnWhenOption = exports.isValidWarnOption = exports.isValidDate = void 0;
const fs = __importStar(require("fs"));
const child_process_1 = require("child_process");
const periods = {
    w: 604800,
    d: 86400,
    h: 3600,
};
const levels = {
    M: 0,
    m: 1,
    p: 2,
};
const isValidDate = (date) => {
    //const regex = new RegExp(/^\d{4}-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])$/)
    //return regex.test(date)
    const [year] = date.split("-");
    return year.length === 4;
};
exports.isValidDate = isValidDate;
const isValidWarnOption = (option) => {
    return option.match(/^\d+[w|d|h]$/) ? option : false;
};
exports.isValidWarnOption = isValidWarnOption;
const isValidWarnWhenOption = (option) => {
    return option.match(/^\d+[M|m|p]$/) ? true : false;
};
exports.isValidWarnWhenOption = isValidWarnWhenOption;
const parseOption = (option) => [
    parseInt(option.substring(0, option.length - 1), 10),
    option.charAt(option.length - 1),
];
exports.parseOption = parseOption;
const parseWarnOption = (option) => {
    if (!(0, exports.isValidWarnOption)(option)) {
        return [1, "w"];
    }
    const [multipler, interval] = (0, exports.parseOption)(option);
    return [multipler, interval];
};
exports.parseWarnOption = parseWarnOption;
const parseWarnWhenOption = (option) => {
    if (!(0, exports.isValidWarnWhenOption)(option)) {
        return [1, levels["p"]];
    }
    const [versionAhead, level] = (0, exports.parseOption)(option);
    return [versionAhead, levels[level]];
};
exports.parseWarnWhenOption = parseWarnWhenOption;
const getWarningPeriod = (warnOption) => {
    if (warnOption === true) {
        return periods["w"];
    }
    const [multipler, interval] = (0, exports.parseWarnOption)(warnOption);
    return multipler * periods[interval];
};
exports.getWarningPeriod = getWarningPeriod;
const startsWithKeyword = (todo, keywords) => {
    return keywords.some((keyword) => {
        return todo.startsWith(`// ${keyword}::`);
    });
};
exports.startsWithKeyword = startsWithKeyword;
const getWarningWhen = (warnOption) => {
    if (warnOption === true) {
        return [1, levels["p"]];
    }
    return (0, exports.parseWarnWhenOption)(warnOption);
};
exports.getWarningWhen = getWarningWhen;
const getSplitPackageVersion = (version) => {
    return version.split(".").map((n) => parseInt(n, 10));
};
exports.getSplitPackageVersion = getSplitPackageVersion;
const getJsonFromFile = (filepath) => {
    try {
        const file = fs.readFileSync(filepath);
        // @ts-ignore
        const data = JSON.parse(file);
        return data;
    }
    catch (_e) {
        return null;
    }
};
exports.getJsonFromFile = getJsonFromFile;
const pipe = (fn, ...fns) => {
    const piped = fns.reduce((prevFn, nextFn) => (value) => nextFn(prevFn(value)), (value) => value);
    return (...args) => piped(fn(...args));
};
exports.pipe = pipe;
const getGitBranch = () => {
    try {
        const callResult = (0, child_process_1.spawnSync)('git', ['rev-parse', '--abbrev-ref', 'HEAD'], { cwd: __dirname });
        const { stdout, stderr } = callResult;
        if (stderr.byteLength) {
            return;
        }
        return stdout.byteLength ? stdout.toString().trim() : undefined;
    }
    catch {
        return undefined;
    }
};
exports.getGitBranch = getGitBranch;
//# sourceMappingURL=utils.js.map