"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.when = void 0;
const typescript_1 = require("typescript");
const utils_1 = require("./utils");
const noerror = {
    error: false,
};
const clean = (version) => {
    const first = version.charAt(0);
    if (["~", "^", "=", ">"].includes(first)) {
        return version.substring(1);
    }
    return version;
};
const compareForWarning = (curr, match, versionAhead) => {
    return match - curr <= versionAhead;
};
const checkEquality = (currentNumbers, matchNumbers) => {
    if (currentNumbers.join("") === matchNumbers.join("")) {
        return {
            currentNumbers,
            matchNumbers,
            state: {
                error: true,
                message: `It's a match, fix it'! Now on ${currentNumbers.join(".")}`,
                category: typescript_1.DiagnosticCategory.Error,
            },
        };
    }
    return {
        currentNumbers,
        matchNumbers,
        state: noerror,
    };
};
const checkForErrors = (currentNumbers, matchNumbers) => {
    const state = currentNumbers.reduce((acc, next, idx) => {
        if (acc.skip) {
            return acc;
        }
        const isIssue = next > matchNumbers[idx] || 0;
        if (isIssue) {
            return {
                skip: true,
                validation: {
                    error: true,
                    message: `Your package has arrived! Now on ${currentNumbers.join(".")}`,
                    category: typescript_1.DiagnosticCategory.Error,
                },
            };
        }
        return next < matchNumbers[idx] || 0
            ? {
                skip: true,
                validation: noerror,
            }
            : acc;
    }, {
        skip: false,
        validation: noerror,
    });
    return {
        currentNumbers,
        matchNumbers,
        state: state.validation,
    };
};
const checkForWarnings = (warningOption) => ({ currentNumbers, matchNumbers, state }) => {
    if (state.error) {
        return state;
    }
    if (warningOption) {
        const [versionAhead, level] = (0, utils_1.getWarningWhen)(warningOption);
        const { validation } = currentNumbers.reduce((acc, next, idx) => {
            if (acc.skip) {
                return acc;
            }
            const shouldWarn = parseInt(currentNumbers.join(""), 10) <
                parseInt(matchNumbers.join(""));
            const isWarning = shouldWarn &&
                idx === level &&
                compareForWarning(next, matchNumbers[idx] || 0, versionAhead);
            if (isWarning) {
                return {
                    skip: true,
                    validation: {
                        error: true,
                        message: `Get ready, your package is on the way!`,
                        category: typescript_1.DiagnosticCategory.Warning,
                    },
                };
            }
            return next < matchNumbers[idx] || 0
                ? {
                    skip: true,
                    validation: noerror,
                }
                : acc;
        }, { skip: false, validation: noerror });
        return validation;
    }
    return noerror;
};
const getWhenIssue = (current, match, options) => {
    const comparator = match.charAt(0);
    const warningOption = options === null || options === void 0 ? void 0 : options.warn;
    const currentNumbers = (0, utils_1.getSplitPackageVersion)(clean(current));
    const matchNumbers = (0, utils_1.getSplitPackageVersion)(clean(match));
    if (comparator === "=") {
        const validation = (0, utils_1.pipe)(checkEquality, checkForWarnings(warningOption))(currentNumbers, matchNumbers);
        return validation;
    }
    if (comparator === ">") {
        const validation = (0, utils_1.pipe)(checkForErrors, checkForWarnings(warningOption))(currentNumbers, matchNumbers);
        return validation;
    }
    return noerror;
};
const when = (conditionParam, config) => {
    var _a, _b;
    if (!config || !conditionParam) {
        return noerror;
    }
    const [dependency, matchVersion] = conditionParam
        .split(",")
        .map((s) => s.replace(/"|'/g, "").trim());
    const packages = {
        ...(_a = config.pjson) === null || _a === void 0 ? void 0 : _a.devDependecies,
        ...(_b = config.pjson) === null || _b === void 0 ? void 0 : _b.dependencies,
    };
    if (!packages[dependency]) {
        return noerror;
    }
    return getWhenIssue(packages[dependency], matchVersion, config.options);
};
exports.when = when;
//# sourceMappingURL=when.js.map